/*
 * graphics.cpp
 *
 *  Created on: 17.10.2009
 *      Author: Jan
 */
#include "libs.h"

GLuint surf2tex(SDL_Surface *surface)
{
	GLuint texture;
	GLenum texture_format;
	GLint  nOfColors;
	if (!surface)
	{
		printf("warning: surface not exists\n");
	}
	if ( (surface->w & (surface->w - 1)) != 0 )
	{
		printf("warning: surface's width is not a power of 2\n");
	}
	if ( (surface->h & (surface->h - 1)) != 0 )
	{
		printf("warning: surface's height is not a power of 2\n");
	}
    // get the number of channels in the SDL surface
    nOfColors = surface->format->BytesPerPixel;
    if (nOfColors == 4)     // contains an alpha channel
    {
    	if (surface->format->Rmask == 0x000000ff)
    		texture_format = GL_RGBA;
        else
        	texture_format = GL_BGRA;
    }
    else
    {
    	if (nOfColors == 3)     // no alpha channel
    	{
    		if (surface->format->Rmask == 0x000000ff)
    			texture_format = GL_RGB;
			else
				texture_format = GL_BGR;
        }
    	else
    	{
    		printf("warning: the image is not truecolor..  this will probably break\n");
    		// this error should not go unhandled
        }
    }
	// Have OpenGL generate a texture object handle for us
	glGenTextures( 1, &texture );
	// Bind the texture object
	glBindTexture( GL_TEXTURE_2D, texture );
	// Set the texture's stretching properties
    glTexParameteri( GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER, GL_LINEAR );
    glTexParameteri( GL_TEXTURE_2D, GL_TEXTURE_MAG_FILTER, GL_LINEAR );
	// Edit the texture object's image data using the information SDL_Surface gives us
	glTexImage2D( GL_TEXTURE_2D, 0, nOfColors, surface->w, surface->h, 0,
			texture_format, GL_UNSIGNED_BYTE, surface->pixels );
	// Free the SDL_Surface only if it was successfully created
	return texture;
}

void menuDraw(SDL_Surface *screen)
{
	glClear(GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT);
	glLoadIdentity();
	glTranslatef(0,0, -10);
	GLuint texture = surf2tex(screen);
	glBindTexture( GL_TEXTURE_2D, texture );
	glBegin( GL_QUADS );
		glTexCoord2i( 0, 0 );		glVertex3f(-1,  1, 8.6);
		glTexCoord2i( 1, 0 );		glVertex3f( 1,  1, 8.6);
		glTexCoord2i( 1, 1 );		glVertex3f( 1, -1, 8.6);
		glTexCoord2i( 0, 1 );		glVertex3f(-1, -1, 8.6);
	glEnd();
	glDeleteTextures( 1, &texture );
	glColor3ub(255, 255, 255);
	SDL_GL_SwapBuffers();
}

void infoBarDraw(SDL_Surface *surface, double x, double y, int w, int h)
{

	glPushMatrix();
		glTranslatef(x,y,0);
		GLuint texture = surf2tex(surface);
		//glBindTexture( GL_TEXTURE_2D, texture );
		glBegin( GL_QUADS );
			glTexCoord2i( 0, 0 );		glVertex3f(-0.25*w,  0.25*h, -10);
			glTexCoord2i( 1, 0 );		glVertex3f( 0.25*w,  0.25*h, -10);
			glTexCoord2i( 1, 1 );		glVertex3f( 0.25*w, -0.25*h, -10);
			glTexCoord2i( 0, 1 );		glVertex3f(-0.25*w, -0.25*h, -10);
		glEnd();
		glDeleteTextures( 1, &texture );
	glPopMatrix();
	/*
	glMatrixMode(GL_PROJECTION);
	glPushMatrix();
		glLoadIdentity();
		glOrtho(0,800,0,600,-1,1);
		glMatrixMode(GL_MODELVIEW);
		glPushMatrix();
			glLoadIdentity();
			glTranslated(0,0,100);
				GLuint texture = surf2tex(surface);
				glBindTexture( GL_TEXTURE_2D, texture );
				glBegin( GL_QUADS );
					glTexCoord2i( 0, 0 );		glVertex2f(-1,  1);
					glTexCoord2i( 1, 0 );		glVertex2f( 1,  1);
					glTexCoord2i( 1, 1 );		glVertex2f( 1, -1);
					glTexCoord2i( 0, 1 );		glVertex2f(-1, -1);
				glEnd();
				glDeleteTextures( 1, &texture );
			glMatrixMode(GL_PROJECTION);
		glPopMatrix();
		glMatrixMode(GL_MODELVIEW);
	glPopMatrix();
	*/
}
